@@ -1,11 +1,16 @@
 package App::GitGrepPerlStatement;
-use 5.014000;
+use 5.008001;
 use strict;
 use warnings;
 use App::GitGrepPerlStatement::StatementFinder;
 use Term::ANSIColor qw(colored);
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
+
+sub say ($) {
+    my ($message) = @_;
+    print $message . "\n";
+}
 
 sub run {
     my ($class, @argv) = @_;
